"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pdf2string = void 0;
const promises_1 = require("node:fs/promises");
const parsePdfFileBuffer = async (pathToFile) => {
    const fileBase64 = await (0, promises_1.readFile)(pathToFile, {});
    return import("pdfjs-dist/legacy/build/pdf.mjs").then(async (pdfjsLib) => {
        const loadingTask = pdfjsLib.getDocument({
            data: new Uint8Array(fileBase64),
        });
        const pdfDocument = await loadingTask.promise;
        const { numPages } = pdfDocument;
        const pageContents = new Array(numPages);
        const pagePromises = [];
        for (let pageNum = 1; pageNum <= numPages; pageNum += 1) {
            pagePromises.push(pdfDocument.getPage(pageNum).then(async (page) => {
                const textContent = await page.getTextContent({
                    includeMarkedContent: false,
                });
                // ? Type assertion of items to TextItem[] should be safe because {includeMarkedContent: false}
                const items = textContent.items;
                if (items.length === 0) {
                    console.log("empty page");
                    pageContents[pageNum - 1] = "";
                }
                else {
                    const pageText = items.map((item) => item.str || "").join(" ");
                    pageContents[pageNum - 1] = pageText;
                }
            }));
        }
        await Promise.all(pagePromises);
        return pageContents;
    });
};
//TODO check more valid types + password
const pdf2string = async (source) => {
    if (typeof source === "string") {
        return parsePdfFileBuffer(source);
        // return console.error("implement");
    }
    if (Buffer.isBuffer(source)) {
        return;
    }
    if (source instanceof Uint8Array) {
        return;
    }
    throw new Error(`Invalid source type: ${typeof source}`);
};
exports.pdf2string = pdf2string;
//# sourceMappingURL=index.js.map